import type { IForwardConfig } from '../types/forwarding.types.js';

/**
 * Updated domain configuration with unified forwarding configuration
 */
export interface IDomainConfig {
  // Core properties - domain patterns
  domains: string[];
  
  // Unified forwarding configuration
  forwarding: IForwardConfig;
  
  // Legacy security properties that will be migrated to forwarding.security
  allowedIPs?: string[];
  blockedIPs?: string[];
  
  // Legacy NetworkProxy properties
  useNetworkProxy?: boolean;
  networkProxyPort?: number;
  
  // Legacy timeout property
  connectionTimeout?: number;
}

/**
 * Helper function to create a domain configuration
 */
export function createDomainConfig(
  domains: string | string[],
  forwarding: IForwardConfig,
  security?: {
    allowedIPs?: string[];
    blockedIPs?: string[];
  }
): IDomainConfig {
  // Normalize domains to an array
  const domainArray = Array.isArray(domains) ? domains : [domains];
  
  return {
    domains: domainArray,
    forwarding,
    allowedIPs: security?.allowedIPs || ['*'],
    blockedIPs: security?.blockedIPs
  };
}